import { Suspense, lazy, useEffect, useRef, useState } from "react";
import Navbar from "@/components/Navbar";
import Hero from "@/components/Hero";  
import Features from "@/components/Features";
import MobileFeatures from "@/components/MobileFeatures";
import DemoArtistDirectory from "@/components/DemoArtistDirectory";
import MobileDemoArtistDirectory from "@/components/MobileDemoArtistDirectory";
import SEOMonitor from "@/components/SEOMonitor";
import { Skeleton } from "@/components/ui/skeleton";
import ErrorBoundary from "@/components/ErrorBoundary";
import { useIsMobile } from "@/hooks/use-mobile";
import SEOHead from "@/components/SEOHead";

// Lazy load components with better grouping for mobile
const HowItWorks = lazy(() => import("@/components/HowItWorks"));
const Disciplines = lazy(() => import("@/components/Disciplines"));

// Mobile-optimized component grouping
const MobileLowerSectionComponents = lazy(() => 
  Promise.all([
    import("@/components/SuccessStories"),
    import("@/components/Testimonials")
  ]).then(([SuccessStories, Testimonials]) => ({
    default: () => (
      <>
        <SuccessStories.default />
        <Testimonials.default />
      </>
    )
  }))
);

// Desktop components (more comprehensive)
const DesktopLowerSectionComponents = lazy(() => 
  Promise.all([
    import("@/components/SuccessStories"),
    import("@/components/Testimonials"),
    import("@/components/FAQ")
  ]).then(([SuccessStories, Testimonials, FAQ]) => ({
    default: () => (
      <>
        <SuccessStories.default />
        <Testimonials.default />
        <FAQ.default />
      </>
    )
  }))
);

const FooterComponents = lazy(() =>
  Promise.all([
    import("@/components/CTA"),
    import("@/components/Footer"),
    import("@/components/CookieBanner")
  ]).then(([CTA, Footer, CookieBanner]) => ({
    default: () => (
      <>
        <CTA.default />
        <Footer.default />
        <CookieBanner.default />
      </>
    )
  }))
);

// Mobile-optimized loading skeleton
const MobileSectionSkeleton = () => (
  <div className="py-8">
    <div className="container mx-auto px-4">
      <Skeleton className="h-6 w-32 mx-auto mb-4" />
      <Skeleton className="h-4 w-48 mx-auto mb-6" />
      <div className="space-y-4">
        {[...Array(2)].map((_, i) => (
          <Skeleton key={i} className="h-24 w-full" />
        ))}
      </div>
    </div>
  </div>
);

// Desktop loading skeleton
const SectionSkeleton = () => (
  <div className="py-12">
    <div className="container mx-auto px-4">
      <Skeleton className="h-8 w-48 mx-auto mb-6" />
      <Skeleton className="h-4 w-72 mx-auto mb-4" />
      <Skeleton className="h-4 w-64 mx-auto mb-8" />
      <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
        {[...Array(3)].map((_, i) => (
          <Skeleton key={i} className="h-32 w-full" />
        ))}
      </div>
    </div>
  </div>
);

// Mobile-optimized intersection observer
const useIntersectionObserver = (threshold = 0.1) => {
  const [isInView, setIsInView] = useState(false);
  const ref = useRef<HTMLDivElement>(null);

  useEffect(() => {
    const observer = new IntersectionObserver(
      ([entry]) => {
        if (entry.isIntersecting) {
          setIsInView(true);
          observer.disconnect();
        }
      },
      { 
        threshold, 
        rootMargin: window.innerWidth < 768 ? '50px' : '100px' // Smaller margin for mobile
      }
    );

    const currentRef = ref.current;
    if (currentRef) {
      observer.observe(currentRef);
    }

    return () => {
      if (currentRef) {
        observer.unobserve(currentRef);
      }
    };
  }, [threshold]);

  return [ref, isInView] as const;
};

// Progressive Loading Component
const ProgressiveSection = ({ 
  children, 
  fallback,
  threshold = 0.1 
}: {
  children: React.ReactNode;
  fallback?: React.ReactNode;
  threshold?: number;
}) => {
  const isMobile = useIsMobile();
  const [ref, isInView] = useIntersectionObserver(threshold);
  
  const defaultFallback = isMobile ? <MobileSectionSkeleton /> : <SectionSkeleton />;
  
  return (
    <div ref={ref}>
      {isInView ? children : (fallback || defaultFallback)}
    </div>
  );
};

const Index = () => {
  const isMobile = useIsMobile();

  // Mobile-optimized preloading
  useEffect(() => {
    const preloadNextSections = () => {
      if (isMobile) {
        // Lighter preloading for mobile
        import("@/components/HowItWorks");
      } else {
        // Full preloading for desktop
        import("@/components/HowItWorks");
        import("@/components/Disciplines");
      }
    };

    let scrollTimeout: NodeJS.Timeout;
    const handleScroll = () => {
      clearTimeout(scrollTimeout);
      scrollTimeout = setTimeout(preloadNextSections, isMobile ? 200 : 100);
    };

    window.addEventListener('scroll', handleScroll, { passive: true });
    return () => {
      window.removeEventListener('scroll', handleScroll);
      clearTimeout(scrollTimeout);
    };
  }, [isMobile]);

  // Structured data para la página principal
  const structuredData = {
    "@context": "https://schema.org",
    "@type": "WebSite",
    "name": "ArtMeeting",
    "url": "https://artmeeting.app",
    "description": "Plataforma de contratación artística que conecta artistas con oportunidades profesionales",
    "potentialAction": {
      "@type": "SearchAction",
      "target": "https://artmeeting.app/search?q={search_term_string}",
      "query-input": "required name=search_term_string"
    }
  };

  return (
    <ErrorBoundary>
      <SEOHead
        title="ArtMeeting - Plataforma de Contratación Artística"
        description="Conecta artistas con oportunidades profesionales. Encuentra y contrata talento artístico de calidad en música, teatro, danza y más."
        keywords="artistas, contratación, música, teatro, danza, arte, espectáculos, España, talento"
        canonical="https://artmeeting.app/"
        ogTitle="ArtMeeting - Encuentra y Contrata Artistas Profesionales"
        ogDescription="La plataforma líder para conectar artistas con oportunidades profesionales en España"
        ogImage="https://artmeeting.app/hero-image.jpg"
        structuredData={structuredData}
      />
      
      <div className="min-h-screen">
        {/* Development monitors */}
        {process.env.NODE_ENV === 'development' && (
          <SEOMonitor />
        )}
        
        {/* Critical above-the-fold components */}
        <ErrorBoundary>
          <Navbar />
        </ErrorBoundary>
        
        <ErrorBoundary>
          <Hero />
        </ErrorBoundary>
        
        <ErrorBoundary>
          {isMobile ? <MobileFeatures /> : <Features />}
        </ErrorBoundary>
        
        {/* Mobile vs Desktop Artist Directory */}
        <ErrorBoundary>
          {isMobile ? <MobileDemoArtistDirectory /> : <DemoArtistDirectory />}
        </ErrorBoundary>
        
        {/* Progressive loading for below-the-fold content */}
        <ProgressiveSection threshold={isMobile ? 0.2 : 0.1}>
          <ErrorBoundary>
            <Suspense fallback={isMobile ? <MobileSectionSkeleton /> : <SectionSkeleton />}>
              <HowItWorks />
            </Suspense>
          </ErrorBoundary>
        </ProgressiveSection>
        
        {/* Desktop-only Disciplines section */}
        {!isMobile && (
          <ProgressiveSection>
            <ErrorBoundary>
              <Suspense fallback={<SectionSkeleton />}>
                <Disciplines />
              </Suspense>
            </ErrorBoundary>
          </ProgressiveSection>
        )}
        
        {/* Mobile vs Desktop lower sections */}
        <ProgressiveSection threshold={0.05}>
          <ErrorBoundary>
            <Suspense fallback={isMobile ? <MobileSectionSkeleton /> : <SectionSkeleton />}>
              {isMobile ? <MobileLowerSectionComponents /> : <DesktopLowerSectionComponents />}
            </Suspense>
          </ErrorBoundary>
        </ProgressiveSection>
        
        <ProgressiveSection threshold={0.05}>
          <ErrorBoundary>
            <Suspense fallback={null}>
              <FooterComponents />
            </Suspense>
          </ErrorBoundary>
        </ProgressiveSection>
      </div>
    </ErrorBoundary>
  );
};

export default Index;
